#!/bin/sh
# -----------------------------------------------------------------------
# /var/install/config.d/owfs-update.sh - paramater update script
#
# Creation   :  2014-08-25 Stephan Sanders
# Last update:  2016-06-14 Stephan Sanders
#
# Copyright (c) 2014-2014 Stephan Sanders, Stephan(at)genlog(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# -----------------------------------------------------------------------

# set package name
package_name=owfs

# include configlib for using printvar
. /var/install/include/configlib

#exec 2> /tmp/owfs-update-trace$$.log
#set -x

# get version
version=$( sed -n '/<version>/ s# ##g; s#</*version>##gp' \
           /var/install/packages/${package_name} )

# ---------------------------------------------------------------------------
# Set the default values for configuration
# ---------------------------------------------------------------------------
START_OWFS='no'

OWFS_SERVER_BUSMASTER='serial'
OWFS_SERVER_DEVICE='/dev/ttyS0'
OWFS_SERVER_IPADDR='4304'

OWFS_SERVER_OWFS='no'
OWFS_SERVER_OWFS_MOUNT='/mnt/owfs'

OWFS_SERVER_HTTPD='no'
OWFS_SERVER_HTTPD_IPADDR='2121'

OWFS_SERVER_FTPD='no'
OWFS_SERVER_FTPD_IPADDR='2120'

#------------------------------------------------------------------------------
# rename variables
#------------------------------------------------------------------------------
rename_old_variables ()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        /var/install/bin/backup-file --quiet ${package_name}
        . /etc/config.d/${package_name}
    fi
}

# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    # -----------------------------------------------------------------------
    printgpl --conf ${package_name} '2014-08-26' 'ssa' 'Stephan Sanders, Stephan[at]genlog(dot)de'
    # -----------------------------------------------------------------------
    echo "# OWFS-VERSION ${version}"
    # -----------------------------------------------------------------------
    printgroup "OWFS (general settings)"
    # -----------------------------------------------------------------------

    printvar 'START_OWFS'
    printcomment             "Start OWFS: 'yes' or 'no'"

    echo
    printvar 'OWFS_SERVER_BUSMASTER'
    printcomment             'Interfacetype'

    printvar 'OWFS_SERVER_DEVICE'
    printcomment             'Options for Device: FAKE, USB,'
    printcomment             '/dev/ttyS0, /dev/i2c-0'

    printvar 'OWFS_SERVER_IPADDR'
    printcomment             'Port or IP:Port for OWAccess'

    echo
    printvar 'OWFS_SERVER_OWFS'
    printcomment             'Starting OW Filesystem'

    printvar 'OWFS_SERVER_OWFS_MOUNT'
    printcomment             'Mountpoint for OWFS local access'

    echo
    printvar 'OWFS_SERVER_HTTPD'
    printcomment             'Starting OW HTTP Server'

    printvar 'OWFS_SERVER_HTTPD_IPADDR'
    printcomment             'Port or IP:Port for HTTP Access'

    echo
    printvar 'OWFS_SERVER_FTPD'
    printcomment             'Starting OW FTP Server'

    printvar 'OWFS_SERVER_FTPD_IPADDR'
    printcomment             'Port or IP:Port for FTP Access'

    # -----------------------------------------------------------------------
    printend
    # -----------------------------------------------------------------------
    } >  $internal_conf_file
    # Set rights
    chmod 0600 $internal_conf_file
    chown root $internal_conf_file
}

# ---------------------------------------------------------------------------
# Create the check.d file
# ---------------------------------------------------------------------------
make_check_file()
{
printgpl --check ${package_name} '2014-08-26' 'ssa' 'Stephan Sanders, Stephan[at]genlog(dot)de' >/etc/check.d/${package_name}
cat >>/etc/check.d/${package_name} <<EOF
# Variable                OPT_VARIABLE      VARIABLE_N   VALUE

START_OWFS                -                   -           YESNO
OWFS_SERVER_BUSMASTER     START_OWFS          -           OWFS_BUSMASTER
OWFS_SERVER_DEVICE        START_OWFS          -           OWFS_DEVICE
OWFS_SERVER_IPADDR        START_OWFS          -           OWFS_PORTADDR
OWFS_SERVER_OWFS          START_OWFS          -           YESNO
OWFS_SERVER_OWFS_MOUNT    OWFS_SERVER_OWFS    -           ABS_PATH
OWFS_SERVER_HTTPD         START_OWFS          -           YESNO
OWFS_SERVER_HTTPD_IPADDR  OWFS_SERVER_HTTPD   -           OWFS_PORTADDR
OWFS_SERVER_FTPD          START_OWFS          -           YESNO
OWFS_SERVER_FTPD_IPADDR   OWFS_SERVER_FTPD    -           OWFS_PORTADDR
EOF


   # Set rights for check.d file
   chmod 0600 /etc/check.d/${package_name}
   chown root /etc/check.d/${package_name}


printgpl --check_exp ${package_name} '2016-06-14' 'ssa' 'Stephan Sanders, Stephan[at]genlog(dot)de' >/etc/check.d/${package_name}.exp
cat >>/etc/check.d/${package_name}.exp <<EOF
OWFS_PORTADDR   = '(RE:PORT)|(RE:IPADDR):(RE:PORT)|(RE:FQDN):(RE:PORT)'
                : 'only Port or IP:Port are allowed'
OWFS_BUSMASTER  = 'serial|passive|DS9490R|HA7Net|HA7S/E|HA5|USB9097|ENET|W1|FAKE|MOCK|TESTER'
                : 'only the following entries are valid: serial|passive|DS9490R|HA7Net|HA7S/E|HA5|USB9097|ENET|W1|FAKE|MOCK|TESTER'
OWFS_DEVICE     = '()|FAKE|USB|all|(RE:OWFS_PORTADDR)|/dev/[[:alpha:]][[:alnum:]]+'
                : 'no valid device port chosen, should be "FAKE", "USB", "all",
                   an ip address, optionally followed by a port number
                    or a device name, e.g. /dev/ttySxx.'
EOF

    # Set rights for check.exp file
    chmod 0600 /etc/check.d/${package_name}.exp
    chown root /etc/check.d/${package_name}.exp

}
# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------
# write default config file
make_config_file /etc/default.d/${package_name}

# update from old version
rename_old_variables

# write new config file
make_config_file /etc/config.d/${package_name}

# write check.d file
make_check_file

exit 0
# ---------------------------------------------------------------------------
# end
#----------------------------------------------------------------------------
