#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/owfs.sh - Apply-Config-Script for owfs
#
# Creation   :  2014-08-25 Stephan Sanders
# Last update:  2016-06-16 Stephan Sanders
#
# Copyright (c) 2014-2016 Stephan Sanders, Stephan(at)genlog(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

#include eislib
. /var/install/include/eislib
. /var/install/include/configlib

# exec 2>/tmp/owfs-trace-$$.log
# set -x

. /etc/config.d/owfs

package_name=owfs

pgmname=`basename $0`
generate_owfsconf=/etc/owfs.conf
generate_aliasfile=/etc/owfs-aliases


# ---------------------------------------------------------------------------
# owfs start
# ---------------------------------------------------------------------------
owfs_start ()
{
    cd /etc/rc2.d
    ln -sf ../init.d/${package_name} S88${package_name}
}

# ---------------------------------------------------------------------------
# owfs stop
# ---------------------------------------------------------------------------
owfs_stop ()
{
    /etc/init.d/${package_name} stop
    rm -f /etc/rc2.d/S??${package_name}
}

#----------------------------------------------------------------------------
# create mount point for owfs
#----------------------------------------------------------------------------
create_owfs_mountpoint ()
{
    if [ "$OWFS_SERVER_OWFS" = "yes" ]
    then
        if [ ! -d "$OWFS_SERVER_OWFS_MOUNT" ]
        then
            mecho --info "Creating Mountpoint at $OWFS_SERVER_OWFS_MOUNT"
            mkdir -p    $OWFS_SERVER_OWFS_MOUNT
            chown root: $OWFS_SERVER_OWFS_MOUNT
            chmod 0777  $OWFS_SERVER_OWFS_MOUNT
        fi
    fi
}

#----------------------------------------------------------------------------
# generate owfs.conf
#----------------------------------------------------------------------------
create_owfs_conf ()
{
    mecho "creating `basename ${generate_owfsconf}` ..."

    {
        printgpl --conf "${pgmname}" "2014-08-11" "ssa" "Stephan Sanders"

        echo "# General settings"
        echo "celsius"
        if [ -f ${generate_aliasfile} ]
        then
            echo "alias = ${generate_aliasfile}"
        fi
        echo ""
        echo "# OWSERVER"
        echo " server: port = $OWFS_SERVER_IPADDR"
        echo "!server: server = localhost:4304"

        # Bus master & device
        case "`echo "$OWFS_SERVER_BUSMASTER" | tr 'A-Z' 'a-z'`" in
            serial )
                # Cheap Interface (resistors & diodes)
                echo " server: passive = $OWFS_SERVER_DEVICE"
                ;;
            ds9490r|ha7net )
                # Dallas USB DS9490R, HA7Net
                echo " server: $OWFS_SERVER_DEVICE"
                ;;
            * )
                echo " server: $OWFS_SERVER_BUSMASTER = $OWFS_SERVER_DEVICE"
                ;;
        esac

        if [ "$OWFS_SERVER_DEVICE" = "FAKE" ]
        then
            echo
            echo "# random simulated device"
            echo "server: FAKE = DS2406,DS2413"
        fi


        if [ "$OWFS_SERVER_OWFS" = "yes" ]
        then
            echo
            echo "# OWFS"
            echo "owfs: mountpoint = $OWFS_SERVER_OWFS_MOUNT"
            echo "owfs: allow_other"
        fi

        if [ "$OWFS_SERVER_HTTPD" = "yes" ]
        then
            echo
            echo "# OWHTTPD"
            echo "http: port = $OWFS_SERVER_HTTPD_IPADDR"
        fi

        if [ "$OWFS_SERVER_FTPD" = "yes" ]
        then
            echo
            echo "# OWFTPD"
            echo "ftp: port = $OWFS_SERVER_FTPD_IPADDR"
        fi
    } > ${generate_owfsconf}
}

#----------------------------------------------------------------------------
# update aliases list
#----------------------------------------------------------------------------
create_owfs_aliases ()
{
    mecho "creating `basename ${generate_aliasfile}` ..."

    _apath=`dirname ${generate_aliasfile}`
    _aname=`basename ${generate_aliasfile}`

    alias_files=`find ${_apath} -maxdepth 1 -name "${_aname}*" | grep -v "${_aname}$"`

    if [ ! -z "${alias_files}" ]
    then
        {
            for FNAME in ${alias_files}
            do
                cat ${FNAME}
                echo
            done
        } > ${generate_aliasfile}
    fi

    # delete empty file
    if [ ! -s "${generate_aliasfile}" ]
    then
        rm -f ${generate_aliasfile}
    fi
}

#============================================================================
# main
#============================================================================

case $1 in
    --alias )
        create_owfs_aliases
        /etc/init.d/owfs --quiet restart
        ;;
    * )
        if [ "$START_OWFS" = "yes" ]
        then
            owfs_start
            create_owfs_mountpoint
            create_owfs_aliases
            create_owfs_conf
        else
            owfs_stop
        fi
        ;;
    esac

#============================================================================
# end
#============================================================================
exit 0
